@@ -38,7 +38,7 @@ module Fugit
         return nil unless s.is_a?(String)
 
 #p s; Raabro.pp(Parser.parse(s, debug: 3), colors: true)
-        h = Parser.parse(s)
+        h = Parser.parse(s.strip)
 
         return nil unless h
 
@@ -60,7 +60,7 @@ module Fugit
         (@hours || [ '*' ]).join(','),
         (@monthdays || [ '*' ]).join(','),
         (@months || [ '*' ]).join(','),
-        (@weekdays || [ [ '*' ] ]).map { |d| d.compact.join('#') }.join(','),
+        weekdays_to_cron_s,
         @timezone ? @timezone.name : nil
           ].compact.join(' ')
     end
@@ -74,6 +74,8 @@ module Fugit
       end
 
       def time; @t; end
+      def to_t; @t; end
+        #
       def to_i; @t.to_i; end
 
       %w[ year month day wday hour min sec wday_in_month rweek rday ]
@@ -165,7 +167,7 @@ module Fugit
 
     def weekday_modulo_match?(nt, mod)
 
-      (nt.rweek + mod[1]) % mod[0] == 0
+      (nt.rweek % mod[0]) == (mod[1] % mod[0])
     end
 
     def weekday_match?(nt)
@@ -197,8 +199,14 @@ module Fugit
 
     def day_match?(nt)
 
-      return weekday_match?(nt) || monthday_match?(nt) \
-        if @weekdays && @monthdays
+      if @weekdays && @monthdays
+
+        return weekday_match?(nt) && monthday_match?(nt) \
+          if @day_and
+            #
+            # extension for fugit, gh-78
+
+        return weekday_match?(nt) || monthday_match?(nt)
           #
           # From `man 5 crontab`
           #
@@ -210,6 +218,8 @@ module Fugit
           # at 4:30 am on the 1st and 15th of each month, plus every Friday.
           #
           # as seen in gh-5 and gh-35
+      end
+
 
       return false unless weekday_match?(nt)
       return false unless monthday_match?(nt)
@@ -480,6 +490,7 @@ module Fugit
 
       @original = original
       @cron_s = nil # just to be sure
+      @day_and = h[:&]
 
       determine_seconds(h[:sec])
       determine_minutes(h[:min])
@@ -498,8 +509,6 @@ module Fugit
 
       sta, edn, sla = r
 
-      sla = nil if sla == 1 # don't get fooled by /1
-
       edn = max if sla && edn.nil?
 
       return [ nil ] if sta.nil? && edn.nil? && sla.nil?
@@ -514,6 +523,8 @@ module Fugit
 
     def range(min, max, sta, edn, sla)
 
+      return [ nil ] if sta == min && edn == max && sla == 1
+
       fail ArgumentError.new(
         'both start and end must be negative in ' +
         { min: min, max: max, sta: sta, edn: edn, sla: sla }.inspect
@@ -620,6 +631,24 @@ module Fugit
       @zone, @timezone = z
     end
 
+    def weekdays_to_cron_s
+
+      return '*' unless @weekdays
+
+      @weekdays
+        .collect { |a|
+          if a.length == 1
+            a[0].to_s
+          elsif a[1].is_a?(Array)
+            a11 = a[1][1]
+            off = (a11 < 0) ? a11.to_s : (a11 > 0) ? "+#{a11}" : ''
+            "#{a[0]}%#{a[1][0]}" + off
+          else
+            a.collect(&:to_s).join('#')
+          end }
+        .join(',')
+    end
+
     module Parser include Raabro
 
       WEEKDAYS =
@@ -640,7 +669,9 @@ module Fugit
       def s(i); rex(nil, i, /[ \t]+/); end
       def star(i); str(nil, i, '*'); end
       def hyphen(i); str(nil, i, '-'); end
-      def comma(i); str(nil, i, ','); end
+      def comma(i); rex(nil, i, /,([ \t]*,)*/); end
+      def comma?(i); rex(nil, i, /([ \t]*,)*/); end
+      def and?(i); rex(nil, i, /&?/); end
 
       def slash(i); rex(:slash, i, /\/\d\d?/); end
 
@@ -700,12 +731,12 @@ module Fugit
       def list_mon(i); jseq(:mon, i, :mon_elt, :comma); end
       def list_dow(i); jseq(:dow, i, :dow_elt_, :comma); end
 
-      def lsec_(i); seq(nil, i, :list_sec, :s); end
-      def lmin_(i); seq(nil, i, :list_min, :s); end
-      def lhou_(i); seq(nil, i, :list_hou, :s); end
-      def ldom_(i); seq(nil, i, :list_dom, :s); end
-      def lmon_(i); seq(nil, i, :list_mon, :s); end
-      alias ldow list_dow
+      def lsec_(i); seq(nil, i, :comma?, :list_sec, :comma?, :s); end
+      def lmin_(i); seq(nil, i, :comma?, :list_min, :comma?, :s); end
+      def lhou_(i); seq(nil, i, :comma?, :list_hou, :comma?, :s); end
+      def ldom_(i); seq(nil, i, :comma?, :list_dom, :comma?, :and?, :s); end
+      def lmon_(i); seq(nil, i, :comma?, :list_mon, :comma?, :s); end
+      def ldow(i); seq(nil, i, :comma?, :list_dow, :comma?, :and?); end
 
       def _tz_name(i)
         rex(nil, i, / +[A-Z][a-zA-Z0-9+\-]+(\/[A-Z][a-zA-Z0-9+\-_]+){0,2}/)
@@ -716,10 +747,12 @@ module Fugit
       def _tz(i); alt(:tz, i, :_tz_delta, :_tz_name); end
 
       def classic_cron(i)
-        seq(:ccron, i, :lmin_, :lhou_, :ldom_, :lmon_, :ldow, :_tz, '?')
+        seq(:ccron, i,
+          :lmin_, :lhou_, :ldom_, :lmon_, :ldow, :_tz, '?')
       end
       def second_cron(i)
-        seq(:scron, i, :lsec_, :lmin_, :lhou_, :ldom_, :lmon_, :ldow, :_tz, '?')
+        seq(:scron, i,
+          :lsec_, :lmin_, :lhou_, :ldom_, :lmon_, :ldow, :_tz, '?')
       end
 
       def cron(i)
@@ -801,6 +834,7 @@ module Fugit
           .inject({}) { |h, tt|
             h[tt.name] = tt.name == :tz ? rewrite_tz(tt) : rewrite_entry(tt)
             h }
+        hcron[:&] = true if t.string.index('&')
 
         z, tz = hcron[:tz]; return nil if z && ! tz
 
