@@ -68,8 +68,10 @@ module Fugit
       hou: { a: 'h', r: 'h', i: 'H', s: 3600, I: true, l: 'hour' },
       min: { a: 'm', r: 'm', i: 'M', s: 60, I: true, l: 'minute' },
       sec: { a: 's', r: 's', i: 'S', s: 1, I: true, l: 'second' } }.freeze
-    INFLA_KEYS, NON_INFLA_KEYS =
-      KEYS.partition { |k, v| v[:I] }.freeze
+
+    INFLA_KEYS, NON_INFLA_KEYS = KEYS
+      .partition { |k, v| v[:I] }
+      .collect(&:freeze)
 
     def _to_s(key)
 
@@ -240,7 +242,7 @@ module Fugit
           n, m = at[1] / 12, at[1] % 12
           at[0], at[1] = at[0] + n, m
         elsif at[1] < 1
-          n, m = -at[1] / 12, -at[1] % 12
+          n, m = (-at[1]) / 12 + 1, (11+at[1]) % 12 + 1
           at[0], at[1] = at[0] - n, m
         end
 
@@ -269,7 +271,7 @@ module Fugit
       when Numeric then add_numeric(-a)
       when Fugit::Duration then add_duration(-a)
       when String then add_duration(-self.class.parse(a))
-      when ::Time, ::EtOrbi::EoTime then add_to_time(a)
+      when ::Time, ::EtOrbi::EoTime then opposite.add_to_time(a)
       else fail ArgumentError.new(
         "cannot subtract #{a.class} instance to a Fugit::Duration")
       end
