@@ -67,6 +67,8 @@ describe Fugit::Cron do
     # gh-5  '0 8 L * * mon-thu', last day of month on Saturday
     #
     # gh-35  '59 6 1-7 * 2', monthdays 1-7 being ignored
+    #
+    # gh-64
 
     # Note: The day of a command's execution can be specified by two fields --
     # day of month, and day of week.  If both fields are restricted (ie, are
@@ -74,6 +76,9 @@ describe Fugit::Cron do
     # time.  For example, ``30 4 1,15 * 5'' would cause a command to be run
     # at 4:30 am on the 1st and 15th of each month, plus every Friday.
 
+    # I need to remember this, else I am going to lose time investigating
+    # those again and again :-(
+
     [ '0 8 L * mon-thu',
       '2018-06-30 08:00:00', '2018-06-28 18:00:00', 'Europe/Berlin' ],
       #
@@ -97,6 +102,12 @@ describe Fugit::Cron do
       '2020-03-01 06:59:00', # not '2020-03-03 06:59:00', monthday 1-7 matches
       '2020-02-29 07:29:00' ],
 
+    [ '0 0 29 2 0,6',     '2022-02-05 00:00:00', '2021-12-27 09:47:00' ],
+    [ '0 0 29 2 sat,sun', '2022-02-05 00:00:00', '2021-12-27 09:47:00' ],
+    [ '0 0 29 2 0,6',     '2022-02-05 00:00:00', '2021-12-27 09:47:00', 'UTC' ],
+      #
+    [ '0 0 11 * 3-6', '2021-12-29 00:00:00', '2021-12-27 09:47:00' ],
+
     #
     # gh-1 '0 9 * * sun%2' and '* * * * sun%2+1'
     #      every other Sunday
@@ -121,6 +132,27 @@ describe Fugit::Cron do
     [ '15/30 * * * *', '2021-02-09 19:15:00', '2021-02-09 19:00:00' ],
     [ '15/30 * * * *', '2021-02-09 19:45:00', '2021-02-09 19:30:00' ],
     [ '15-40/30 * * * *', '2021-02-09 20:15:00', '2021-02-09 19:30:00' ],
+
+    # gh-67
+
+    [ '30 18 * * 2#5', '2022-03-29 18:30', '2022-03-08', 'UTC' ],
+    [ '30 18 * * 2#5', '2022-03-29 18:30', '2022-03-08', 'Europe/Paris' ],
+    [ '30 18 * * 2#5 Europe/Paris', '2022-03-29 16:30', '2022-03-08', 'UTC' ],
+
+    # gh-78
+      # by way of gh-75
+
+    [ '0 0 */2 * 1-5',   '2022-08-10 00:00', '2022-08-09', 'UTC' ],
+    [ '0 0 */2 * 1-5&',  '2022-08-11 00:00', '2022-08-09', 'UTC' ],
+    [ '0 0 */2& * 1-5',  '2022-08-11 00:00', '2022-08-09', 'UTC' ],
+    [ '0 0 */2& * 1-5&', '2022-08-11 00:00', '2022-08-09', 'UTC' ],
+
+      # by way of gh-35
+
+    [ '59 6 1-7 * 2',    '2020-03-17 06:59', '2020-03-15', 'UTC' ],
+    [ '59 6 1-7 * 2&',   '2020-04-07 06:59', '2020-03-15', 'UTC' ],
+    [ '59 6 1-7& * 2',   '2020-04-07 06:59', '2020-03-15', 'UTC' ],
+    [ '59 6 1-7& * 2&',  '2020-04-07 06:59', '2020-03-15', 'UTC' ],
   ]
 
   describe '#next_time' do
@@ -315,6 +347,32 @@ describe Fugit::Cron do
         end
       end
 
+      it 'correctly increments into DST (America/New_York) (gh-63)' do
+
+        in_zone 'America/New_York' do
+
+          c = Fugit::Cron.parse('30 4 * * *')
+          #t = EtOrbi::EoTime.parse('2021-03-11 12:00:00')
+          t = Time.parse('2021-03-11 12:00:00')
+
+          points =
+            6.times.collect do
+              t = c.next_time(t)
+              tu = t.dup.utc
+              "#{t.strftime('%F_%H:%M_%Z')}__#{tu.strftime('%F_%H:%M_%Z')}"
+            end
+
+          expect(points.join("\n")).to eq(%w[
+            2021-03-12_04:30_EST__2021-03-12_09:30_UTC
+            2021-03-13_04:30_EST__2021-03-13_09:30_UTC
+            2021-03-14_04:30_EDT__2021-03-14_08:30_UTC
+            2021-03-15_04:30_EDT__2021-03-15_08:30_UTC
+            2021-03-16_04:30_EDT__2021-03-16_08:30_UTC
+            2021-03-17_04:30_EDT__2021-03-17_08:30_UTC
+          ].join("\n"))
+        end
+      end
+
       it 'correctly increments out of DST (gh-53 e)' do
 
         in_zone 'Europe/Zurich' do
@@ -714,19 +772,41 @@ describe Fugit::Cron do
         expect(cron0.next_time('2021-04-21 07:00:00').to_s
           ).to eq(cron1.next_time('2021-04-21 07:00:00').to_s)
       end
+
+      it 'does not break on "30 14 * * 4%4+3" (gh-76)' do
+
+        t0 =
+          Time.utc(2022, 9, 12, 12, 1, 1, 0)
+        nt =
+          Fugit::Cron.do_parse('30 14 * * 4%4+3 Australia/Melbourne')
+            .next_time(t0)
+
+        #expect(nt.to_s).to eq(/^2022-10-06 03:30:00 (Z|\+0000)$/)
+          # post gh-47
+        expect(nt.to_s).to match(/^2022-09-22 04:30:00 (Z|\+0000)$/)
+          # post gh-76
+
+        in_zone('Australia/Melbourne') do
+          #expect(nt.to_t.to_s).to eq('2022-10-06 14:30:00 +1100') # post gh-47
+          expect(nt.to_t.to_s).to eq('2022-09-22 14:30:00 +1000') # post gh-76
+        end
+      end
     end
   end
 
   describe '#match?' do
 
-    NEXT_TIMES.each do |cron, next_time, _|
+    NEXT_TIMES.each do |cron, next_time, _, zone_name|
 
       it "succeeds #{cron.inspect} ? #{next_time.inspect}" do
 
-        c = Fugit::Cron.parse(cron)
-        ent = Time.parse(next_time)
+        in_zone(zone_name) do
 
-        expect(c.match?(ent)).to be(true)
+          c = Fugit::Cron.parse(cron)
+          ent = Time.parse(next_time)
+
+          expect(c.match?(ent)).to be(true)
+        end
       end
     end
 
@@ -1065,10 +1145,15 @@ describe Fugit::Cron do
         [ '* * * 1 *', '* * * 1 *' ],  # and that 01 is a month
         [ '* * * 01 *', '* * * 1 *' ], #
 
-        [ '*/15 * * * *', '0,15,30,45 * * * *' ],               # gh-19
-        [ '/15 * * * *', '0,15,30,45 * * * *' ],                #
-        [ '/15 * * * * *', '0,15,30,45 * * * * *' ],            #
-        [ '/15 /4 * * *', '0,15,30,45 0,4,8,12,16,20 * * *' ],  #
+        [ '*/15 * * * *', '0,15,30,45 * * * *' ],              # gh-19
+        [ '/15 * * * *', '0,15,30,45 * * * *' ],               #
+        [ '/15 * * * * *', '0,15,30,45 * * * * *' ],           #
+        [ '/15 /4 * * *', '0,15,30,45 0,4,8,12,16,20 * * *' ], #
+        [ '0/15 * * * *', '0,15,30,45 * * * *' ],              #
+
+        [ '15/30 * * * *', '15,45 * * * *' ], # gh-56
+        [ '15-40/30 * * * *', '15 * * * *' ], #
+        [ '0 4/12 * * *', '0 4,16 * * *' ],   #
 
         [ '0 18 * * fri-sun UTC', '0 18 * * 0,5,6 UTC' ], # gh-27
 
@@ -1106,11 +1191,40 @@ describe Fugit::Cron do
           #
           # gh-43
 
+        [ '1 /1 * * *', '1 * * * *' ],
         [ '1 */1 * * *', '1 * * * *' ],
-        [ '1 0/1 * * *', '1 0 * * *' ],
-        [ '1 0-23/1 * * *', "1 #{(0..23).map(&:to_s).join(',')} * * *" ],
+        [ '1 0/1 * * *', '1 * * * *' ],
+        [ '1 0-23/1 * * *', '1 * * * *' ],
           #
-          # some cronds are different, see https://crontab.guru/#7_0/1_*_*_*
+          # cronds differ, see https://crontab.guru/#7_0/1_*_*_*
+          # 2022-09-20, gh-79, changing...
+          #
+        [ '0 * * * *', '0 * * * *' ],                          # gh-79
+        [ '0 * * * * Asia/Kabul', '0 * * * * Asia/Kabul' ],    #
+        [ '0 /1 * * *', '0 * * * *' ],                         #
+        [ '0 /1 * * * Asia/Kabul', '0 * * * * Asia/Kabul' ],   #
+        [ '0 */1 * * *', '0 * * * *' ],                        #
+        [ '0 */1 * * * Asia/Kabul', '0 * * * * Asia/Kabul' ],  #
+        [ '0 0/1 * * *', '0 * * * *' ],                        #
+        [ '0 0/1 * * * Asia/Kabul', '0 * * * * Asia/Kabul' ],  #
+          #
+        [ '0 7/5 * * *', '0 7,12,17,22 * * *' ],
+        [ '0 7/5 * * * Asia/Kabul', '0 7,12,17,22 * * * Asia/Kabul' ],
+        [ '0 7-17/5 * * *', '0 7,12,17 * * *' ],
+        [ '0 7-17/5 * * * Asia/Kabul', '0 7,12,17 * * * Asia/Kabul' ],
+
+        [ '0 0/4 * * *', '0 0,4,8,12,16,20 * * *' ],
+        [ '0/30 * * * *', '0,30 * * * *' ],
+        [ '0/10 * * * 1-5 Africa/Juba', '0,10,20,30,40,50 * * * 1,2,3,4,5 Africa/Juba' ],
+        [ '0 4/12 * * *', '0 4,16 * * *' ],
+        [ '0 0/12 * * * -09:00', '0 0,12 * * * -09:00' ],
+        [ '30 7/4 * * *', '30 7,11,15,19,23 * * *' ],
+
+        [ '9,,19 * * * *', '9,19 * * * *' ],
+        [ ',8 * * * *', '8 * * * *' ],
+        [ ',,10,,20, * * * *', '10,20 * * * *' ],
+        [ '10,,20 * 1,,11,,21, * *', '10,20 * 1,11,21 * *' ],
+        [ ',,10,,22, * * * * Asia/Omsk', '10,22 * * * * Asia/Omsk' ],
 
       ].each { |c, e|
 
@@ -1359,17 +1473,22 @@ describe Fugit::Cron do
 
   describe '#to_cron_s' do
 
-    [
+    cron_s = {
 
-      [ '0 */3 * * 1,2', '0 0,3,6,9,12,15,18,21 * * 1,2' ],
-      [ '0 5 * * 1,2,3,4,5', '0 5 * * 1,2,3,4,5' ],
-      [ '0 5 * * 1-4,fri#3', '0 5 * * 1,2,3,4,5#3' ],
-      [ '* * * * * America/Los_Angeles', '* * * * * America/Los_Angeles' ],
-      #[ '0 */3 * * 1,2', '0 */3 * * 1-2' ],
-      #[ '0 5 * * 1,2,3,4,5', '0 5 * * 1-5' ],
-      #[ '0 5 * * 1,2,3,4,fri#3', '0 5 * * 1-4,5#3' ],
+      '0 */3 * * 1,2' => '0 0,3,6,9,12,15,18,21 * * 1,2',
+      '0 5 * * 1,2,3,4,5' => '0 5 * * 1,2,3,4,5',
+      '0 5 * * 1-4,fri#3' => '0 5 * * 1,2,3,4,5#3',
+      '* * * * * America/Los_Angeles' => '* * * * * America/Los_Angeles',
+      '0 13 * * wed' => '0 13 * * 3',
+      '0 13 * * wed%2' => '0 13 * * 3%2',
+      '0 13 * * wed%2+1' => '0 13 * * 3%2+1',
 
-    ].each do |source, target|
+      '0 0 L * *' => '0 0 -1 * *',
+      '23 1-15/2 * * *' => '23 1,3,5,7,9,11,13,15 * * *',
+      '* * * * sun#L' => '* * * * 0#-1',
+    }
+
+    cron_s.each do |source, target|
 
       it "represents #{source.inspect} into #{target.inspect}" do
 
@@ -1381,12 +1500,15 @@ describe Fugit::Cron do
       end
     end
 
-    it "produces the same cron if parsing again the to_cron_s" do
+    cron_s.each do |k, _|
 
-      c1 = Fugit::Cron.parse('* * * * * America/Los_Angeles')
-      c2 = Fugit::Cron.parse(c1.to_cron_s)
+      it "produces the same cron string if parsing (#{k.inspect} to_cron_s)" do
 
-      expect(c1).to eq(c2)
+        ck = Fugit::Cron.parse(k)
+        cks = Fugit::Cron.parse(ck.to_cron_s)
+
+        expect(cks).to eq(ck)
+      end
     end
   end
 
@@ -1506,3 +1628,30 @@ describe Fugit::Cron do
   end
 end
 
+describe Fugit do
+
+  describe '#parse_cron' do
+
+    [
+
+      [ "45 5 * * sun", '45 5 * * 0' ],
+      [ "\n45 5 * * sun \n ", '45 5 * * 0' ],
+      [ "*   *  last  * *", '* * -1 * *' ],
+      [ " *   *  last  * *\n", '* * -1 * *' ],
+      [ "30 18 * * 2#5 Europe/Paris", '30 18 * * 2#5 Europe/Paris' ],
+      [ " 30 18 * * 2#5  Europe/Paris \n", '30 18 * * 2#5 Europe/Paris' ],
+
+    ].each do |src, cron_s|
+
+      it "parses #{src.inspect}" do
+
+        r = Fugit.parse_cron(src)
+
+        expect(r.class).to eq(Fugit::Cron)
+        expect(r.original).to eq(src)
+        expect(r.to_cron_s).to eq(cron_s)
+      end
+    end
+  end
+end
+
