@@ -90,6 +90,30 @@ describe Fugit::Nat do
           #
           # gh-42
 
+        'every day at 5pm'      => '0 17 * * *',
+        'every day at 5:00pm'   => '0 17 * * *',
+        'every day at 5:00 pm'  => '0 17 * * *',
+          #
+        'every day at 12am'      => '0 0 * * *',
+        'every day at 12pm'      => '0 12 * * *',
+        'every day at 12:00am'   => '0 0 * * *',
+        'every day at 12:00pm'   => '0 12 * * *',
+        'every day at 12:00 am'  => '0 0 * * *',
+        'every day at 12:00 pm'  => '0 12 * * *',
+        'every day at 12:15am'   => '15 0 * * *',
+        'every day at 12:15pm'   => '15 12 * * *',
+        'every day at 12:15 am'  => '15 0 * * *',
+        'every day at 12:15 pm'  => '15 12 * * *',
+          #
+        'every day at 12 noon'         => '0 12 * * *',
+        'every day at 12 midnight'     => '0 24 * * *',
+        'every day at 12:00 noon'      => '0 12 * * *',
+        'every day at 12:00 midnight'  => '0 24 * * *',
+        'every day at 12:15 noon'      => '15 12 * * *',
+        'every day at 12:15 midnight'  => '15 24 * * *',
+          #
+          # gh-81
+
         #'every day at 18:15 and 20:45' => '* * * * *',
           #
           # gh-24 see below
@@ -286,3 +310,28 @@ describe Fugit::Nat do
   end
 end
 
+describe Fugit do
+
+  describe '.parse_nat' do
+
+    {
+
+      "every day at five" => '0 5 * * *',
+      "every day at 5 pm in Asia/Tokyo" => '0 17 * * * Asia/Tokyo',
+      " \nevery day at five \n" => '0 5 * * *',
+      "\n every day at 5 pm  in Asia/Tokyo\n" => '0 17 * * * Asia/Tokyo',
+
+    }.each do |src, cron_s|
+
+      it "strips and parses #{src.inspect}" do
+
+        r = Fugit.parse_nat(src)
+
+        expect(r.class).to eq(Fugit::Cron)
+        expect(r.to_cron_s).to eq(cron_s)
+      end
+    end
+  end
+end
+
+
